@@ -12,6 +12,7 @@
 namespace Symfony\Component\Yaml\Tests;
 
 use PHPUnit\Framework\TestCase;
+use Symfony\Bridge\PhpUnit\ExpectDeprecationTrait;
 use Symfony\Component\Yaml\Exception\ParseException;
 use Symfony\Component\Yaml\Parser;
 use Symfony\Component\Yaml\Tag\TaggedValue;
@@ -19,8 +20,9 @@ use Symfony\Component\Yaml\Yaml;
 
 class ParserTest extends TestCase
 {
-    /** @var Parser */
-    protected $parser;
+    use ExpectDeprecationTrait;
+
+    private ?Parser $parser;
 
     protected function setUp(): void
     {
@@ -34,6 +36,88 @@ class ParserTest extends TestCase
         chmod(__DIR__.'/Fixtures/not_readable.yml', 0644);
     }
 
+    public function testTopLevelNumber()
+    {
+        $yml = '5';
+        $data = $this->parser->parse($yml);
+        $expected = 5;
+        $this->assertSameData($expected, $data);
+    }
+
+    public function testTopLevelNull()
+    {
+        $yml = 'null';
+        $data = $this->parser->parse($yml);
+        $expected = null;
+        $this->assertSameData($expected, $data);
+    }
+
+    public function testTaggedValueTopLevelNumber()
+    {
+        $yml = '!number 5';
+        $data = $this->parser->parse($yml, Yaml::PARSE_CUSTOM_TAGS);
+        $expected = new TaggedValue('number', 5);
+        $this->assertSameData($expected, $data);
+    }
+
+    public function testTaggedValueTopLevelNull()
+    {
+        $yml = '!tag null';
+        $data = $this->parser->parse($yml, Yaml::PARSE_CUSTOM_TAGS);
+
+        $this->assertSameData(new TaggedValue('tag', null), $data);
+    }
+
+    public function testTaggedValueTopLevelString()
+    {
+        $yml = '!user barbara';
+        $data = $this->parser->parse($yml, Yaml::PARSE_CUSTOM_TAGS);
+        $expected = new TaggedValue('user', 'barbara');
+        $this->assertSameData($expected, $data);
+    }
+
+    public function testTaggedValueTopLevelAssocInline()
+    {
+        $yml = '!user { name: barbara }';
+        $data = $this->parser->parse($yml, Yaml::PARSE_CUSTOM_TAGS);
+        $expected = new TaggedValue('user', ['name' => 'barbara']);
+        $this->assertSameData($expected, $data);
+    }
+
+    public function testTaggedValueTopLevelAssoc()
+    {
+        $yml = <<<'YAML'
+!user
+name: barbara
+YAML;
+        $data = $this->parser->parse($yml, Yaml::PARSE_CUSTOM_TAGS);
+        $expected = new TaggedValue('user', ['name' => 'barbara']);
+        $this->assertSameData($expected, $data);
+    }
+
+    public function testTaggedValueTopLevelList()
+    {
+        $yml = <<<'YAML'
+!users
+- barbara
+YAML;
+        $data = $this->parser->parse($yml, Yaml::PARSE_CUSTOM_TAGS);
+        $expected = new TaggedValue('users', ['barbara']);
+        $this->assertSameData($expected, $data);
+    }
+
+    public function testTaggedTextAsListItem()
+    {
+        $yml = <<<'YAML'
+- !text |
+  first line
+YAML;
+        // @todo Fix the parser, eliminate this exception.
+        $this->expectException(ParseException::class);
+        $this->expectExceptionMessage('Unable to parse at line 2 (near "!text |").');
+        $this->parser->parse($yml, Yaml::PARSE_CUSTOM_TAGS);
+    }
+
     /**
      * @dataProvider getDataFormSpecifications
      */
@@ -42,14 +126,14 @@ class ParserTest extends TestCase
         $this->assertEquals($expected, var_export($this->parser->parse($yaml), true), $comment);
     }
 
-    public function getDataFormSpecifications()
+    public static function getDataFormSpecifications()
     {
-        return $this->loadTestsFromFixtureFiles('index.yml');
+        return self::loadTestsFromFixtureFiles('index.yml');
     }
 
-    public function getNonStringMappingKeysData()
+    public static function getNonStringMappingKeysData()
     {
-        return $this->loadTestsFromFixtureFiles('nonStringKeys.yml');
+        return self::loadTestsFromFixtureFiles('nonStringKeys.yml');
     }
 
     /**
@@ -62,7 +146,7 @@ class ParserTest extends TestCase
         $this->parser->parse($given);
     }
 
-    public function invalidIndentation(): array
+    public static function invalidIndentation(): array
     {
         return [
             [
@@ -104,10 +188,10 @@ class ParserTest extends TestCase
     public function testValidTokenSeparation(string $given, array $expected)
     {
         $actual = $this->parser->parse($given);
-        $this->assertEquals($expected, $actual);
+        $this->assertSameData($expected, $actual);
     }
 
-    public function validTokenSeparators(): array
+    public static function validTokenSeparators(): array
     {
         return [
             [
@@ -140,7 +224,7 @@ EOF;
         $this->assertEquals('foo', $this->parser->parse($yaml));
     }
 
-    public function getBlockChompingTests()
+    public static function getBlockChompingTests()
     {
         $tests = [];
 
@@ -482,7 +566,7 @@ EOF;
 foo: !php/object O:30:"Symfony\Component\Yaml\Tests\B":1:{s:1:"b";s:3:"foo";}
 bar: 1
 EOF;
-        $this->assertEquals(['foo' => new B(), 'bar' => 1], $this->parser->parse($input, Yaml::PARSE_OBJECT), '->parse() is able to parse objects');
+        $this->assertSameData(['foo' => new B(), 'bar' => 1], $this->parser->parse($input, Yaml::PARSE_OBJECT), '->parse() is able to parse objects');
     }
 
     public function testObjectSupportDisabledButNoExceptions()
@@ -491,7 +575,7 @@ EOF;
 foo: !php/object O:30:"Symfony\Tests\Component\Yaml\B":1:{s:1:"b";s:3:"foo";}
 bar: 1
 EOF;
-        $this->assertEquals(['foo' => null, 'bar' => 1], $this->parser->parse($input), '->parse() does not parse objects');
+        $this->assertSameData(['foo' => null, 'bar' => 1], $this->parser->parse($input), '->parse() does not parse objects');
     }
 
     /**
@@ -501,10 +585,10 @@ EOF;
     {
         $flags = Yaml::PARSE_OBJECT_FOR_MAP;
 
-        $this->assertEquals($expected, $this->parser->parse($yaml, $flags));
+        $this->assertSameData($expected, $this->parser->parse($yaml, $flags));
     }
 
-    public function getObjectForMapTests()
+    public static function getObjectForMapTests()
     {
         $tests = [];
 
@@ -751,7 +835,7 @@ EOT;
         $this->assertSame($expected, $this->parser->parse($yaml));
     }
 
-    public function getParseExceptionNotAffectedMultiLineStringLastResortParsing()
+    public static function getParseExceptionNotAffectedMultiLineStringLastResortParsing()
     {
         $tests = [];
 
@@ -888,12 +972,12 @@ EOD;
     public function testParseExceptionOnDuplicate($input, $duplicateKey, $lineNumber)
     {
         $this->expectException(ParseException::class);
-        $this->expectExceptionMessage(sprintf('Duplicate key "%s" detected at line %d', $duplicateKey, $lineNumber));
+        $this->expectExceptionMessage(\sprintf('Duplicate key "%s" detected at line %d', $duplicateKey, $lineNumber));
 
         Yaml::parse($input);
     }
 
-    public function getParseExceptionOnDuplicateData()
+    public static function getParseExceptionOnDuplicateData()
     {
         $tests = [];
 
@@ -956,12 +1040,12 @@ EOD;
 hash:
 EOF;
 
-        $this->assertEquals(['hash' => null], Yaml::parse($input));
+        $this->assertSame(['hash' => null], Yaml::parse($input));
     }
 
     public function testCommentAtTheRootIndent()
     {
-        $this->assertEquals([
+        $this->assertSame([
             'services' => [
                 'app.foo_service' => [
                     'class' => 'Foo',
@@ -987,7 +1071,7 @@ EOF
 
     public function testStringBlockWithComments()
     {
-        $this->assertEquals(['content' => <<<'EOT'
+        $this->assertSame(['content' => <<<'EOT'
 # comment 1
 header
 
@@ -1015,7 +1099,7 @@ EOF
 
     public function testFoldedStringBlockWithComments()
     {
-        $this->assertEquals([['content' => <<<'EOT'
+        $this->assertSame([['content' => <<<'EOT'
 # comment 1
 header
 
@@ -1044,7 +1128,7 @@ EOF
 
     public function testNestedFoldedStringBlockWithComments()
     {
-        $this->assertEquals([[
+        $this->assertSame([[
             'title' => 'some title',
             'content' => <<<'EOT'
 # comment 1
@@ -1056,7 +1140,7 @@ header
     </body>
 
 footer # comment3
-EOT
+EOT,
         ]], Yaml::parse(<<<'EOF'
 -
     title: some title
@@ -1076,7 +1160,7 @@ EOF
 
     public function testReferenceResolvingInInlineStrings()
     {
-        $this->assertEquals([
+        $this->assertSame([
             'var' => 'var-value',
             'scalar' => 'var-value',
             'list' => ['var-value'],
@@ -1116,7 +1200,7 @@ EOF
 foo: 1
 bar: 2
 EOF;
-        $this->assertEquals(['foo' => 1, 'bar' => 2], $this->parser->parse($yaml));
+        $this->assertSame(['foo' => 1, 'bar' => 2], $this->parser->parse($yaml));
     }
 
     public function testFloatKeys()
@@ -1166,7 +1250,7 @@ EOF;
             '~' => 'null',
         ];
 
-        $this->assertEquals($expected, $this->parser->parse($yaml));
+        $this->assertSame($expected, $this->parser->parse($yaml));
     }
 
     public function testColonInMappingValueException()
@@ -1198,7 +1282,7 @@ EOT;
         $this->assertSame($expectedParserResult, $this->parser->parse($yaml));
     }
 
-    public function getCommentLikeStringInScalarBlockData()
+    public static function getCommentLikeStringInScalarBlockData()
     {
         $tests = [];
 
@@ -1383,7 +1467,7 @@ EOT
         $this->assertSame(['data' => 'Hello world'], $this->parser->parse($data));
     }
 
-    public function getBinaryData()
+    public static function getBinaryData()
     {
         return [
             'enclosed with double quotes' => ['data: !!binary "SGVsbG8gd29ybGQ="'],
@@ -1393,14 +1477,14 @@ EOT
                 <<<'EOT'
 data: !!binary |
     SGVsbG8gd29ybGQ=
-EOT
-    ],
+EOT,
+            ],
             'containing spaces in block scalar' => [
                 <<<'EOT'
 data: !!binary |
     SGVs bG8gd 29ybGQ=
-EOT
-    ],
+EOT,
+            ],
         ];
     }
 
@@ -1415,7 +1499,7 @@ EOT
         $this->parser->parse($data);
     }
 
-    public function getInvalidBinaryData()
+    public static function getInvalidBinaryData()
     {
         return [
             'length not a multiple of four' => ['data: !!binary "SGVsbG8d29ybGQ="', '/The normalized base64 encoded data \(data without whitespace characters\) length must be a multiple of four \(\d+ bytes given\)/'],
@@ -1457,33 +1541,40 @@ EOT
         ];
     }
 
+    public function testParseDateWithSubseconds()
+    {
+        $yaml = <<<'EOT'
+date: 2002-12-14T01:23:45.670000Z
+EOT;
+
+        $this->assertSameData(['date' => 1039829025.67], $this->parser->parse($yaml));
+    }
+
     public function testParseDateAsMappingValue()
     {
         $yaml = <<<'EOT'
 date: 2002-12-14
 EOT;
-        $expectedDate = new \DateTime();
-        $expectedDate->setTimeZone(new \DateTimeZone('UTC'));
-        $expectedDate->setDate(2002, 12, 14);
-        $expectedDate->setTime(0, 0, 0);
+        $expectedDate = (new \DateTimeImmutable())
+            ->setTimeZone(new \DateTimeZone('UTC'))
+            ->setDate(2002, 12, 14)
+            ->setTime(0, 0, 0);
 
-        $this->assertEquals(['date' => $expectedDate], $this->parser->parse($yaml, Yaml::PARSE_DATETIME));
+        $this->assertSameData(['date' => $expectedDate], $this->parser->parse($yaml, Yaml::PARSE_DATETIME));
     }
 
     /**
-     * @param $lineNumber
-     * @param $yaml
      * @dataProvider parserThrowsExceptionWithCorrectLineNumberProvider
      */
     public function testParserThrowsExceptionWithCorrectLineNumber($lineNumber, $yaml)
     {
         $this->expectException(ParseException::class);
-        $this->expectExceptionMessage(sprintf('Unexpected characters near "," at line %d (near "bar: "123",").', $lineNumber));
+        $this->expectExceptionMessage(\sprintf('Unexpected characters near "," at line %d (near "bar: "123",").', $lineNumber));
 
         $this->parser->parse($yaml);
     }
 
-    public function parserThrowsExceptionWithCorrectLineNumberProvider()
+    public static function parserThrowsExceptionWithCorrectLineNumberProvider()
     {
         return [
             [
@@ -1493,7 +1584,7 @@ foo:
     -
         # bar
         bar: "123",
-YAML
+YAML,
             ],
             [
                 5,
@@ -1503,7 +1594,7 @@ foo:
         # bar
         # bar
         bar: "123",
-YAML
+YAML,
             ],
             [
                 8,
@@ -1516,7 +1607,7 @@ bar:
     -
         # bar
         bar: "123",
-YAML
+YAML,
             ],
             [
                 10,
@@ -1531,7 +1622,7 @@ bar:
         # bar
         # bar
         bar: "123",
-YAML
+YAML,
             ],
         ];
     }
@@ -1619,6 +1710,34 @@ YAML;
         $this->assertSame($expected, $this->parser->parse($yaml));
     }
 
+    /**
+     * @dataProvider wrappedUnquotedStringsProvider
+     */
+    public function testWrappedUnquotedStringWithMultipleSpacesInValue(string $yaml, array $expected)
+    {
+        $this->assertSame($expected, $this->parser->parse($yaml));
+    }
+
+    public static function wrappedUnquotedStringsProvider()
+    {
+        return [
+            'mapping' => [
+                '{ foo: bar  bar, fiz: cat      cat }',
+                [
+                    'foo' => 'bar  bar',
+                    'fiz' => 'cat      cat',
+                ],
+            ],
+            'sequence' => [
+                '[ bar  bar, cat      cat ]',
+                [
+                    'bar  bar',
+                    'cat      cat',
+                ],
+            ],
+        ];
+    }
+
     public function testParseMultiLineUnquotedString()
     {
         $yaml = <<<EOT
@@ -1632,6 +1751,69 @@ EOT;
         $this->assertSame(['foo' => 'bar baz foobar foo', 'bar' => 'baz'], $this->parser->parse($yaml));
     }
 
+    /**
+     * @dataProvider unquotedStringWithTrailingComment
+     */
+    public function testParseMultiLineUnquotedStringWithTrailingComment(string $yaml, array $expected)
+    {
+        $this->assertSame($expected, $this->parser->parse($yaml));
+    }
+
+    public static function unquotedStringWithTrailingComment()
+    {
+        return [
+            'comment after comma' => [
+                <<<'YAML'
+                {
+                    foo: 3, # comment
+                    bar: 3
+                }
+                YAML,
+                ['foo' => 3, 'bar' => 3],
+            ],
+            'comment after space' => [
+                <<<'YAML'
+                {
+                    foo: 3 # comment
+                }
+                YAML,
+                ['foo' => 3],
+            ],
+            'comment after space, but missing space after #' => [
+                <<<'YAML'
+                {
+                    foo: 3 #comment
+                }
+                YAML,
+                ['foo' => 3],
+            ],
+            'comment after tab' => [
+                <<<YAML
+                {
+                    foo: 3\t# comment
+                }
+                YAML,
+                ['foo' => 3],
+            ],
+            'comment after tab, but missing space after #' => [
+                <<<YAML
+                {
+                    foo: 3\t#comment
+                }
+                YAML,
+                ['foo' => 3],
+            ],
+            '# in mapping value' => [
+                <<<'YAML'
+                {
+                    foo: example.com/#about
+                }
+                YAML,
+                ['foo' => 'example.com/#about'],
+            ],
+        ];
+    }
+
     /**
      * @dataProvider escapedQuotationCharactersInQuotedStrings
      */
@@ -1640,7 +1822,7 @@ EOT;
         $this->assertSame($expected, $this->parser->parse($yaml));
     }
 
-    public function escapedQuotationCharactersInQuotedStrings()
+    public static function escapedQuotationCharactersInQuotedStrings()
     {
         return [
             'single quoted string' => [
@@ -1687,7 +1869,7 @@ YAML
 
     public function testParseMultiLineString()
     {
-        $this->assertEquals("foo bar\nbaz", $this->parser->parse("foo\nbar\n\nbaz"));
+        $this->assertSame("foo bar\nbaz", $this->parser->parse("foo\nbar\n\nbaz"));
     }
 
     /**
@@ -1695,10 +1877,10 @@ YAML
      */
     public function testParseMultiLineMappingValue($yaml, $expected, $parseError)
     {
-        $this->assertEquals($expected, $this->parser->parse($yaml));
+        $this->assertSame($expected, $this->parser->parse($yaml));
     }
 
-    public function multiLineDataProvider()
+    public static function multiLineDataProvider()
     {
         $tests = [];
 
@@ -1762,10 +1944,10 @@ EOF;
      */
     public function testInlineNotationSpanningMultipleLines($expected, string $yaml)
     {
-        $this->assertEquals($expected, $this->parser->parse($yaml));
+        $this->assertSame($expected, $this->parser->parse($yaml));
     }
 
-    public function inlineNotationSpanningMultipleLinesProvider(): array
+    public static function inlineNotationSpanningMultipleLinesProvider(): array
     {
         return [
             'mapping' => [
@@ -1831,7 +2013,7 @@ YAML
                 <<<YAML
 [ foo, [bar, baz]
 ]
-YAML
+YAML,
             ],
             'nested sequence spanning multiple lines' => [
                 [
@@ -1843,7 +2025,7 @@ YAML
     ['entry1', {}],
     ['entry2']
 ]
-YAML
+YAML,
             ],
             'sequence nested in mapping' => [
                 ['foo' => ['bar', 'foobar'], 'bar' => ['baz']],
@@ -1885,7 +2067,7 @@ foobar: [
     bar,
 ]
 bar: baz
-YAML
+YAML,
             ],
             'nested sequence nested in mapping starting on the same line' => [
                 [
@@ -2012,7 +2194,7 @@ YAML
 foo: 'bar
 
 baz'
-YAML
+YAML,
             ],
             'mixed mapping with inline notation having separated lines' => [
                 [
@@ -2028,7 +2210,7 @@ map: {
     a: "b"
 }
 param: "some"
-YAML
+YAML,
             ],
             'mixed mapping with inline notation on one line' => [
                 [
@@ -2041,7 +2223,20 @@ YAML
                 <<<YAML
 map: {key: "value", a: "b"}
 param: "some"
-YAML
+YAML,
+            ],
+            'mixed mapping with inline notation on one line with a comment' => [
+                [
+                    'map' => [
+                        'key' => 'value',
+                        'a' => 'b',
+                    ],
+                    'param' => 'some',
+                ],
+                <<<YAML
+map: {key: "value", a: "b"} # comment
+param: "some"
+YAML,
             ],
             'mixed mapping with compact inline notation on one line' => [
                 [
@@ -2055,7 +2250,7 @@ YAML
 map: {key: "value",
 a: "b"}
 param: "some"
-YAML
+YAML,
             ],
             'nested collections containing strings with bracket chars' => [
                 [
@@ -2095,7 +2290,7 @@ YAML
         foo: 'bar}'
     }
 ]
-YAML
+YAML,
             ],
             'escaped characters in quoted strings' => [
                 [
@@ -2116,7 +2311,7 @@ YAML
     ['te''st'],
     ["te\"st]"]
 ]
-YAML
+YAML,
             ],
         ];
     }
@@ -2134,9 +2329,33 @@ YAML;
         $this->parser->parse($yaml);
     }
 
+    public function testInlineMappingFollowedByMoreContentIsInvalid()
+    {
+        $this->expectException(ParseException::class);
+        $this->expectExceptionMessage('Unexpected token "baz" at line 1 (near "{ foo: bar } baz").');
+
+        $yaml = <<<YAML
+{ foo: bar } baz
+YAML;
+
+        $this->parser->parse($yaml);
+    }
+
+    public function testInlineSequenceFollowedByMoreContentIsInvalid()
+    {
+        $this->expectException(ParseException::class);
+        $this->expectExceptionMessage('Unexpected token ",bar," at line 1 (near "[\'foo\'],bar,").');
+
+        $yaml = <<<YAML
+['foo'],bar,
+YAML;
+
+        $this->parser->parse($yaml);
+    }
+
     public function testTaggedInlineMapping()
     {
-        $this->assertEquals(new TaggedValue('foo', ['foo' => 'bar']), $this->parser->parse('!foo {foo: bar}', Yaml::PARSE_CUSTOM_TAGS));
+        $this->assertSameData(new TaggedValue('foo', ['foo' => 'bar']), $this->parser->parse('!foo {foo: bar}', Yaml::PARSE_CUSTOM_TAGS));
     }
 
     public function testInvalidInlineSequenceContainingStringWithEscapedQuotationCharacter()
@@ -2151,10 +2370,10 @@ YAML;
      */
     public function testCustomTagSupport($expected, $yaml)
     {
-        $this->assertEquals($expected, $this->parser->parse($yaml, Yaml::PARSE_CUSTOM_TAGS));
+        $this->assertSameData($expected, $this->parser->parse($yaml, Yaml::PARSE_CUSTOM_TAGS));
     }
 
-    public function taggedValuesProvider()
+    public static function taggedValuesProvider()
     {
         return [
             'scalars' => [
@@ -2167,7 +2386,7 @@ foo: !inline bar
 quz: !long >
   this is a long
   text
-YAML
+YAML,
             ],
             'sequences' => [
                 [new TaggedValue('foo', ['yaml']), new TaggedValue('quz', ['bar'])],
@@ -2175,7 +2394,7 @@ YAML
 - !foo
     - yaml
 - !quz [bar]
-YAML
+YAML,
             ],
             'mappings' => [
                 new TaggedValue('foo', ['foo' => new TaggedValue('quz', ['bar']), 'quz' => new TaggedValue('foo', ['quz' => 'bar'])]),
@@ -2184,14 +2403,14 @@ YAML
 foo: !quz [bar]
 quz: !foo
    quz: bar
-YAML
+YAML,
             ],
             'inline' => [
                 [new TaggedValue('foo', ['foo', 'bar']), new TaggedValue('quz', ['foo' => 'bar', 'quz' => new TaggedValue('bar', ['one' => 'bar'])])],
                 <<<YAML
 - !foo [foo, bar]
 - !quz {foo: bar, quz: !bar {one: bar}}
-YAML
+YAML,
             ],
             'spaces-around-tag-value-in-sequence' => [
                 [new TaggedValue('foo', 'bar')],
@@ -2207,7 +2426,7 @@ YAML
     baz
     #bar
   ]]
-YAML
+YAML,
             ],
             'with-comments-trailing-comma' => [
                 [
@@ -2219,14 +2438,14 @@ YAML
     baz,
     #bar
   ]]
-YAML
+YAML,
             ],
         ];
     }
 
     public function testNonSpecificTagSupport()
     {
-        $this->assertSame('12', $this->parser->parse('! 12'));
+        $this->assertSame(12, $this->parser->parse('! 12'));
     }
 
     public function testCustomTagsDisabled()
@@ -2310,7 +2529,7 @@ INI;
         $this->parser->parse($ini);
     }
 
-    private function loadTestsFromFixtureFiles($testsFile)
+    private static function loadTestsFromFixtureFiles($testsFile)
     {
         $parser = new Parser();
 
@@ -2347,7 +2566,7 @@ INI;
         $yamlString = Yaml::dump($trickyVal);
         $arrayFromYaml = $this->parser->parse($yamlString);
 
-        $this->assertEquals($trickyVal, $arrayFromYaml);
+        $this->assertSame($trickyVal, $arrayFromYaml);
     }
 
     public function testParserCleansUpReferencesBetweenRuns()
@@ -2400,6 +2619,17 @@ YAML;
         $this->parser->parse('!php/const:App\Kernel::SEMART_VERSION', Yaml::PARSE_CUSTOM_TAGS | Yaml::PARSE_CONSTANT);
     }
 
+    /**
+     * @group legacy
+     */
+    public function testDeprecatedPhpConstantSyntaxAsScalarKey()
+    {
+        $this->expectDeprecation('Since symfony/yaml 6.2: YAML syntax for key "!php/const:Symfony\Component\Yaml\Tests\B::BAR" is deprecated and replaced by "!php/const Symfony\Component\Yaml\Tests\B::BAR".');
+        $actual = $this->parser->parse('!php/const:Symfony\Component\Yaml\Tests\B::BAR: value', Yaml::PARSE_CUSTOM_TAGS | Yaml::PARSE_CONSTANT);
+
+        $this->assertSame(['bar' => 'value'], $actual);
+    }
+
     public function testPhpConstantTagMappingAsScalarKey()
     {
         $yaml = <<<YAML
@@ -2462,7 +2692,7 @@ YAML;
             ],
         ];
 
-        $this->assertEquals($expected, $this->parser->parse($yaml, Yaml::PARSE_OBJECT_FOR_MAP));
+        $this->assertSameData($expected, $this->parser->parse($yaml, Yaml::PARSE_OBJECT_FOR_MAP));
     }
 
     public function testFilenamesAreParsedAsStringsWithoutFlag()
@@ -2555,7 +2785,7 @@ YAML;
             ],
         ];
 
-        $this->assertEquals($expected, $this->parser->parse($yaml, Yaml::PARSE_OBJECT_FOR_MAP));
+        $this->assertSameData($expected, $this->parser->parse($yaml, Yaml::PARSE_OBJECT_FOR_MAP));
     }
 
     public function testEvalRefException()
@@ -2578,7 +2808,7 @@ EOE;
         $this->parser->parse($yaml, Yaml::PARSE_CUSTOM_TAGS);
     }
 
-    public function circularReferenceProvider()
+    public static function circularReferenceProvider()
     {
         $tests = [];
 
@@ -2610,6 +2840,44 @@ YAML;
         return $tests;
     }
 
+    public function testBlockScalarArray()
+    {
+        $yaml = <<<'YAML'
+anyOf:
+  - $ref: >-
+      #/string/bar
+anyOfMultiline:
+  - $ref: >-
+      #/string/bar
+      second line
+nested:
+  anyOf:
+    - $ref: >-
+        #/string/bar
+YAML;
+        $expected = [
+            'anyOf' => [
+                0 => [
+                    '$ref' => '#/string/bar',
+                ],
+            ],
+            'anyOfMultiline' => [
+                0 => [
+                    '$ref' => '#/string/bar second line',
+                ],
+            ],
+            'nested' => [
+                'anyOf' => [
+                    0 => [
+                        '$ref' => '#/string/bar',
+                    ],
+                ],
+            ],
+        ];
+
+        $this->assertSame($expected, $this->parser->parse($yaml));
+    }
+
     /**
      * @dataProvider indentedMappingData
      */
@@ -2618,7 +2886,7 @@ YAML;
         $this->assertSame($expected, $this->parser->parse($yaml));
     }
 
-    public function indentedMappingData()
+    public static function indentedMappingData()
     {
         $tests = [];
 
@@ -2830,6 +3098,20 @@ YAML;
             'regular_space' => 'a b',
         ], $this->parser->parse($expected));
     }
+
+    public function testSkipBlankLines()
+    {
+        $this->assertSame(['foo' => [null]], (new Parser())->parse("foo:\n-\n\n"));
+    }
+
+    private function assertSameData($expected, $actual)
+    {
+        $this->assertEquals($expected, $actual);
+        $this->assertSame(
+            var_export($expected, true),
+            var_export($actual, true)
+        );
+    }
 }
 
 class B
